@@ -10,6 +10,7 @@ from enum import Enum
 
 import numpy as np
 import pandas as pd
+import torch
 from bson.objectid import ObjectId
 
 from monty.json import MontyDecoder, MontyEncoder, MSONable, _load_redirect, jsanitize
@@ -302,6 +303,20 @@ class JsonTest(unittest.TestCase):
         listobj2 = json.loads(s, cls=MontyDecoder)
         self.assertEqual(listobj2[0].a.a, 1)
 
+    def test_torch(self):
+        t = torch.tensor([0, 1, 2])
+        jsonstr = json.dumps(t, cls=MontyEncoder)
+        t2 = json.loads(jsonstr, cls=MontyDecoder)
+        self.assertEqual(type(t2), torch.Tensor)
+        self.assertEqual(t2.type(), t.type())
+        self.assertTrue(np.array_equal(t2, t))
+        t = torch.tensor([1 + 1j, 2 + 1j])
+        jsonstr = json.dumps(t, cls=MontyEncoder)
+        t2 = json.loads(jsonstr, cls=MontyDecoder)
+        self.assertEqual(type(t2), torch.Tensor)
+        self.assertEqual(t2.type(), t.type())
+        self.assertTrue(np.array_equal(t2, t))
+
     def test_datetime(self):
         dt = datetime.datetime.now()
         jsonstr = json.dumps(dt, cls=MontyEncoder)
@@ -314,6 +329,8 @@ class JsonTest(unittest.TestCase):
         d = json.loads(jsonstr, cls=MontyDecoder)
         self.assertEqual(type(d["dt"]), datetime.datetime)
 
+        jsanitize(dt, strict=True)
+
     def test_uuid(self):
         from uuid import UUID, uuid4
 
@@ -396,7 +413,6 @@ class JsonTest(unittest.TestCase):
         self.assertEqual(obj.np_a["a"][0]["b"][0][1], 2 + 1j)
 
     def test_pandas(self):
-
         cls = ClassContainingDataFrame(df=pd.DataFrame([{"a": 1, "b": 1}, {"a": 1, "b": 2}]))
 
         d = json.loads(MontyEncoder().encode(cls))
@@ -673,7 +689,6 @@ class JsonTest(unittest.TestCase):
         assert obj.a.b == 1
 
     def test_dataclass(self):
-
         c = Coordinates([Point(1, 2), Point(3, 4)])
         d = c.as_dict()
         c2 = Coordinates.from_dict(d)
